==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/DaprPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.DaprPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Indicates some additional properties for dapr client type
 * @property componentType The dapr component type
 * @property metadata Additional dapr metadata
 * @property scopes The dapr component scopes
 * @property secretStoreComponent The name of a secret store dapr to retrieve secret
 * @property version The dapr component version
 */
public data class DaprPropertiesArgs(
    public val componentType: Output<String>? = null,
    public val metadata: Output<List<DaprMetadataArgs>>? = null,
    public val scopes: Output<List<String>>? = null,
    public val secretStoreComponent: Output<String>? = null,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.DaprPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.servicelinker.inputs.DaprPropertiesArgs =
        com.pulumi.azurenative.servicelinker.inputs.DaprPropertiesArgs.builder()
            .componentType(componentType?.applyValue({ args0 -> args0 }))
            .metadata(
                metadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .scopes(scopes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .secretStoreComponent(secretStoreComponent?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DaprPropertiesArgs].
 */
@PulumiTagMarker
public class DaprPropertiesArgsBuilder internal constructor() {
    private var componentType: Output<String>? = null

    private var metadata: Output<List<DaprMetadataArgs>>? = null

    private var scopes: Output<List<String>>? = null

    private var secretStoreComponent: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value The dapr component type
     */
    @JvmName("qdsosoyufftbmaox")
    public suspend fun componentType(`value`: Output<String>) {
        this.componentType = value
    }

    /**
     * @param value Additional dapr metadata
     */
    @JvmName("wlgttowueuqjaxkb")
    public suspend fun metadata(`value`: Output<List<DaprMetadataArgs>>) {
        this.metadata = value
    }

    @JvmName("vcbfmshummuitede")
    public suspend fun metadata(vararg values: Output<DaprMetadataArgs>) {
        this.metadata = Output.all(values.asList())
    }

    /**
     * @param values Additional dapr metadata
     */
    @JvmName("sukkveevemyqjgbl")
    public suspend fun metadata(values: List<Output<DaprMetadataArgs>>) {
        this.metadata = Output.all(values)
    }

    /**
     * @param value The dapr component scopes
     */
    @JvmName("onghuqspieiokwux")
    public suspend fun scopes(`value`: Output<List<String>>) {
        this.scopes = value
    }

    @JvmName("avdihmqxbfdbsitr")
    public suspend fun scopes(vararg values: Output<String>) {
        this.scopes = Output.all(values.asList())
    }

    /**
     * @param values The dapr component scopes
     */
    @JvmName("ehvdbuflcrngjsry")
    public suspend fun scopes(values: List<Output<String>>) {
        this.scopes = Output.all(values)
    }

    /**
     * @param value The name of a secret store dapr to retrieve secret
     */
    @JvmName("kphqcuctlxhlkfol")
    public suspend fun secretStoreComponent(`value`: Output<String>) {
        this.secretStoreComponent = value
    }

    /**
     * @param value The dapr component version
     */
    @JvmName("pkvegpujawuyfnys")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value The dapr component type
     */
    @JvmName("dayyihvdtmssqajp")
    public suspend fun componentType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.componentType = mapped
    }

    /**
     * @param value Additional dapr metadata
     */
    @JvmName("jdaukckpdstgmoxh")
    public suspend fun metadata(`value`: List<DaprMetadataArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param argument Additional dapr metadata
     */
    @JvmName("bqpdpkckyhiipstm")
    public suspend fun metadata(argument: List<suspend DaprMetadataArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DaprMetadataArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.metadata = mapped
    }

    /**
     * @param argument Additional dapr metadata
     */
    @JvmName("oskhdyygtkgjufwg")
    public suspend fun metadata(vararg argument: suspend DaprMetadataArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DaprMetadataArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.metadata = mapped
    }

    /**
     * @param argument Additional dapr metadata
     */
    @JvmName("jkfvhfifsxouqsox")
    public suspend fun metadata(argument: suspend DaprMetadataArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DaprMetadataArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.metadata = mapped
    }

    /**
     * @param values Additional dapr metadata
     */
    @JvmName("mjhaydyaefpgtkbm")
    public suspend fun metadata(vararg values: DaprMetadataArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param value The dapr component scopes
     */
    @JvmName("rjuastwiyadrpvsc")
    public suspend fun scopes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scopes = mapped
    }

    /**
     * @param values The dapr component scopes
     */
    @JvmName("iptbpugaltmewqvn")
    public suspend fun scopes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scopes = mapped
    }

    /**
     * @param value The name of a secret store dapr to retrieve secret
     */
    @JvmName("extresieppfpoyut")
    public suspend fun secretStoreComponent(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretStoreComponent = mapped
    }

    /**
     * @param value The dapr component version
     */
    @JvmName("ydidslxtaupujxov")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): DaprPropertiesArgs = DaprPropertiesArgs(
        componentType = componentType,
        metadata = metadata,
        scopes = scopes,
        secretStoreComponent = secretStoreComponent,
        version = version,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/DaprPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.DaprPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Indicates some additional properties for dapr client type
 * @property componentType The dapr component type
 * @property metadata Additional dapr metadata
 * @property scopes The dapr component scopes
 * @property secretStoreComponent The name of a secret store dapr to retrieve secret
 * @property version The dapr component version
 */
public data class DaprPropertiesArgs(
    public val componentType: Output<String>? = null,
    public val metadata: Output<List<DaprMetadataArgs>>? = null,
    public val scopes: Output<List<String>>? = null,
    public val secretStoreComponent: Output<String>? = null,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.DaprPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.servicelinker.inputs.DaprPropertiesArgs =
        com.pulumi.azurenative.servicelinker.inputs.DaprPropertiesArgs.builder()
            .componentType(componentType?.applyValue({ args0 -> args0 }))
            .metadata(
                metadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .scopes(scopes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .secretStoreComponent(secretStoreComponent?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DaprPropertiesArgs].
 */
@PulumiTagMarker
public class DaprPropertiesArgsBuilder internal constructor() {
    private var componentType: Output<String>? = null

    private var metadata: Output<List<DaprMetadataArgs>>? = null

    private var scopes: Output<List<String>>? = null

    private var secretStoreComponent: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value The dapr component type
     */
    @JvmName("arnwqssgxintfqeh")
    public suspend fun componentType(`value`: Output<String>) {
        this.componentType = value
    }

    /**
     * @param value Additional dapr metadata
     */
    @JvmName("mdfkdifxuerrdbkw")
    public suspend fun metadata(`value`: Output<List<DaprMetadataArgs>>) {
        this.metadata = value
    }

    @JvmName("pfkghapvfqdsgrpe")
    public suspend fun metadata(vararg values: Output<DaprMetadataArgs>) {
        this.metadata = Output.all(values.asList())
    }

    /**
     * @param values Additional dapr metadata
     */
    @JvmName("pganptkljrrwwtxd")
    public suspend fun metadata(values: List<Output<DaprMetadataArgs>>) {
        this.metadata = Output.all(values)
    }

    /**
     * @param value The dapr component scopes
     */
    @JvmName("fkgnckjswdpppapk")
    public suspend fun scopes(`value`: Output<List<String>>) {
        this.scopes = value
    }

    @JvmName("fgaiwxnsbcgthtbv")
    public suspend fun scopes(vararg values: Output<String>) {
        this.scopes = Output.all(values.asList())
    }

    /**
     * @param values The dapr component scopes
     */
    @JvmName("cqsoyrnoongairbr")
    public suspend fun scopes(values: List<Output<String>>) {
        this.scopes = Output.all(values)
    }

    /**
     * @param value The name of a secret store dapr to retrieve secret
     */
    @JvmName("facohseijjqhxlsi")
    public suspend fun secretStoreComponent(`value`: Output<String>) {
        this.secretStoreComponent = value
    }

    /**
     * @param value The dapr component version
     */
    @JvmName("eudyxbajkmcmbfnu")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value The dapr component type
     */
    @JvmName("sfjpaxpjwqogmige")
    public suspend fun componentType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.componentType = mapped
    }

    /**
     * @param value Additional dapr metadata
     */
    @JvmName("xtqwbiovmfnqfadw")
    public suspend fun metadata(`value`: List<DaprMetadataArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param argument Additional dapr metadata
     */
    @JvmName("rbcqtyuyuvqyuwnp")
    public suspend fun metadata(argument: List<suspend DaprMetadataArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DaprMetadataArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.metadata = mapped
    }

    /**
     * @param argument Additional dapr metadata
     */
    @JvmName("frkqvqxtyyhygesk")
    public suspend fun metadata(vararg argument: suspend DaprMetadataArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DaprMetadataArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.metadata = mapped
    }

    /**
     * @param argument Additional dapr metadata
     */
    @JvmName("nvadenlmbeoiljan")
    public suspend fun metadata(argument: suspend DaprMetadataArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DaprMetadataArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.metadata = mapped
    }

    /**
     * @param values Additional dapr metadata
     */
    @JvmName("sntjxygvyqcwlohd")
    public suspend fun metadata(vararg values: DaprMetadataArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param value The dapr component scopes
     */
    @JvmName("awknhsifqalqvbhq")
    public suspend fun scopes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scopes = mapped
    }

    /**
     * @param values The dapr component scopes
     */
    @JvmName("kbsmtsoqnmwsgvni")
    public suspend fun scopes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scopes = mapped
    }

    /**
     * @param value The name of a secret store dapr to retrieve secret
     */
    @JvmName("ovmhkidqrsmwppmo")
    public suspend fun secretStoreComponent(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretStoreComponent = mapped
    }

    /**
     * @param value The dapr component version
     */
    @JvmName("gyvkkrfidqlefytf")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): DaprPropertiesArgs = DaprPropertiesArgs(
        componentType = componentType,
        metadata = metadata,
        scopes = scopes,
        secretStoreComponent = secretStoreComponent,
        version = version,
    )
}
